==> msp430-periph-0.0.2.crate: msp430-periph-0.0.2/src/peripherals/csys_1.rs <==
//! CSYS  Compact System Module

utils::periph! {
    /// CSYS  Compact System Module
    CSYS;
    /// System control
    rw SYSCTL @ 0x00: u16 = 0_0 {
        /// SYS - RAM based interrupt vectors
        SYSRIVECT: 0 = struct SYSRIVECT(bool);
        /// SYS - PMM access protect
        SYSPMMPE: 2 = struct SYSPMMPE(bool);
        /// SYS - TCK/RST indication detected
        SYSBSLIND: 4 = struct SYSBSLIND(bool);
        /// SYS - Dedicated JTAG pins enabled
        SYSJTAGPIN: 5 = struct SYSJTAGPIN(bool);
    }
    /// Boot strap configuration area
    rw SYSBSLC @ 0x02: u16 = 0_0 {
        /// SYS - BSL Protection Size 0
        SYSBSLSIZE0: 0 = struct SYSBSLSIZE0(bool);
        /// SYS - BSL Protection Size 1
        SYSBSLSIZE1: 1 = struct SYSBSLSIZE1(bool);
        /// SYS - RAM assigned to BSL
        SYSBSLR: 2 = struct SYSBSLR(bool);
        /// SYS - BSL Memory disabled
        SYSBSLOFF: 14 = struct SYSBSLOFF(bool);
        /// SYS - BSL Memory protection enabled
        SYSBSLPE: 15 = struct SYSBSLPE(bool);
    }
    /// JTAG mailbox control
    rw SYSJMBC @ 0x06: u16 = 0_0 {
        /// SYS - Incoming JTAG Mailbox 0 Flag
        JMBIN0FG: 0 = struct JMBIN0FG(bool);
        /// SYS - Incoming JTAG Mailbox 1 Flag
        JMBIN1FG: 1 = struct JMBIN1FG(bool);
        /// SYS - Outgoing JTAG Mailbox 0 Flag
        JMBOUT0FG: 2 = struct JMBOUT0FG(bool);
        /// SYS - Outgoing JTAG Mailbox 1 Flag
        JMBOUT1FG: 3 = struct JMBOUT1FG(bool);
        /// SYS - JMB 16/32 Bit Mode
        JMBMODE: 4 = struct JMBMODE(bool);
        /// SYS - Incoming JTAG Mailbox 0 Flag auto-clear disalbe
        JMBCLR0OFF: 6 = struct JMBCLR0OFF(bool);
        /// SYS - Incoming JTAG Mailbox 1 Flag auto-clear disalbe
        JMBCLR1OFF: 7 = struct JMBCLR1OFF(bool);
    }
    /// JTAG mailbox input 0
    rw SYSJMBI0 @ 0x08: u16 = 0_0 {
        /// JTAG mailbox input 0
        SYSJMBI0: 0..15 = struct SYSJMBI0Field(u16);
    }
    /// JTAG mailbox input 1
    rw SYSJMBI1 @ 0x0a: u16 = 0_0 {
        /// JTAG mailbox input 1
        SYSJMBI1: 0..15 = struct SYSJMBI1Field(u16);
    }
    /// JTAG mailbox output 0
    rw SYSJMBO0 @ 0x0c: u16 = 0_0 {
        /// JTAG mailbox output 0
        SYSJMBO0: 0..15 = struct SYSJMBO0Field(u16);
    }
    /// JTAG mailbox output 1
    rw SYSJMBO1 @ 0x0e: u16 = 0_0 {
        /// JTAG mailbox output 1
        SYSJMBO1: 0..15 = struct SYSJMBO1Field(u16);
    }
    /// System Configuration Register
    rw SYSCNF @ 0x10: u16 = 0_0 {
        /// SYS - SVM output enable
        SVMOE: 2 = struct SVMOE(bool);
        /// SYS - SVM based Ports off flag
        SVMPO: 3 = struct SVMPO(bool);
        /// SYS - Incoming JTAG Mailbox 0 Flag
        SVMPD: 4 = struct SVMPD(bool);
        /// SYS - SVM based port disable
        SVMEN: 5 = struct SVMEN(bool);
        /// SYS - Write lock enable for configuration RAM
        RAMLCK0: 8 = struct RAMLCK0(bool);
        /// SYS - Write lock enable for applicationon RAM
        RAMLCK1: 9 = struct RAMLCK1(bool);
    }
    /// Bus Error vector generator
    rw SYSBERRIV @ 0x18: u16 = 0_0 {
        /// Bus Error vector generator
        SYSBERRIV: 0..15 = struct SYSBERRIVField(u16);
    }
    /// User NMI vector generator
    rw SYSUNIV @ 0x1a: u16 = 0_0 {
        /// User NMI vector generator
        SYSUNIV: 0..15 = struct SYSUNIVField(u16);
    }
    /// System NMI vector generator
    rw SYSSNIV @ 0x1c: u16 = 0_0 {
        /// System NMI vector generator
        SYSSNIV: 0..15 = struct SYSSNIVField(u16);
    }
    /// Reset vector generator
    rw SYSRSTIV @ 0x1e: u16 = 0_0 {
        /// Reset vector generator
        SYSRSTIV: 0..15 = struct SYSRSTIVField(u16);
    }
}

==> msp430-periph-0.0.4.crate: msp430-periph-0.0.4/src/peripherals/csys_1.rs <==
//! CSYS  Compact System Module

utils::periph! {
    /// CSYS  Compact System Module
    CSYS;
    /// System control
    rw CTL @ 0x00: u16 = 0_0 {
        /// SYS - RAM based interrupt vectors
        RIVECT: 0 = struct RIVECT(bool);
        /// SYS - PMM access protect
        PMMPE: 2 = struct PMMPE(bool);
        /// SYS - TCK/RST indication detected
        BSLIND: 4 = struct BSLIND(bool);
        /// SYS - Dedicated JTAG pins enabled
        JTAGPIN: 5 = struct JTAGPIN(bool);
    }
    /// Boot strap configuration area
    rw BSLC @ 0x02: u16 = 0_0 {
        /// SYS - BSL Protection Size 0
        BSLSIZE0: 0 = struct BSLSIZE0(bool);
        /// SYS - BSL Protection Size 1
        BSLSIZE1: 1 = struct BSLSIZE1(bool);
        /// SYS - RAM assigned to BSL
        BSLR: 2 = struct BSLR(bool);
        /// SYS - BSL Memory disabled
        BSLOFF: 14 = struct BSLOFF(bool);
        /// SYS - BSL Memory protection enabled
        BSLPE: 15 = struct BSLPE(bool);
    }
    /// JTAG mailbox control
    rw JMBC @ 0x06: u16 = 0_0 {
        /// SYS - Incoming JTAG Mailbox 0 Flag
        JMBIN0FG: 0 = struct JMBIN0FG(bool);
        /// SYS - Incoming JTAG Mailbox 1 Flag
        JMBIN1FG: 1 = struct JMBIN1FG(bool);
        /// SYS - Outgoing JTAG Mailbox 0 Flag
        JMBOUT0FG: 2 = struct JMBOUT0FG(bool);
        /// SYS - Outgoing JTAG Mailbox 1 Flag
        JMBOUT1FG: 3 = struct JMBOUT1FG(bool);
        /// SYS - JMB 16/32 Bit Mode
        JMBMODE: 4 = struct JMBMODE(bool);
        /// SYS - Incoming JTAG Mailbox 0 Flag auto-clear disalbe
        JMBCLR0OFF: 6 = struct JMBCLR0OFF(bool);
        /// SYS - Incoming JTAG Mailbox 1 Flag auto-clear disalbe
        JMBCLR1OFF: 7 = struct JMBCLR1OFF(bool);
    }
    /// JTAG mailbox input 0
    rw JMBI0 @ 0x08: u16 = 0_0 {
        /// JTAG mailbox input 0
        JMBI0: 0..15 = struct JMBI0Field(u16);
    }
    /// JTAG mailbox input 1
    rw JMBI1 @ 0x0a: u16 = 0_0 {
        /// JTAG mailbox input 1
        JMBI1: 0..15 = struct JMBI1Field(u16);
    }
    /// JTAG mailbox output 0
    rw JMBO0 @ 0x0c: u16 = 0_0 {
        /// JTAG mailbox output 0
        JMBO0: 0..15 = struct JMBO0Field(u16);
    }
    /// JTAG mailbox output 1
    rw JMBO1 @ 0x0e: u16 = 0_0 {
        /// JTAG mailbox output 1
        JMBO1: 0..15 = struct JMBO1Field(u16);
    }
    /// System Configuration Register
    rw CNF @ 0x10: u16 = 0_0 {
        /// SYS - SVM output enable
        SVMOE: 2 = struct SVMOE(bool);
        /// SYS - SVM based Ports off flag
        SVMPO: 3 = struct SVMPO(bool);
        /// SYS - Incoming JTAG Mailbox 0 Flag
        SVMPD: 4 = struct SVMPD(bool);
        /// SYS - SVM based port disable
        SVMEN: 5 = struct SVMEN(bool);
        /// SYS - Write lock enable for configuration RAM
        RAMLCK0: 8 = struct RAMLCK0(bool);
        /// SYS - Write lock enable for applicationon RAM
        RAMLCK1: 9 = struct RAMLCK1(bool);
    }
    /// Bus Error vector generator
    rw BERRIV @ 0x18: u16 = 0_0 {
        /// Bus Error vector generator
        BERRIV: 0..15 = struct BERRIVField(u16);
    }
    /// User NMI vector generator
    rw UNIV @ 0x1a: u16 = 0_0 {
        /// User NMI vector generator
        UNIV: 0..15 = struct UNIVField(u16);
    }
    /// System NMI vector generator
    rw SNIV @ 0x1c: u16 = 0_0 {
        /// System NMI vector generator
        SNIV: 0..15 = struct SNIVField(u16);
    }
    /// Reset vector generator
    rw RSTIV @ 0x1e: u16 = 0_0 {
        /// Reset vector generator
        RSTIV: 0..15 = struct RSTIVField(u16);
    }
}
